==> xscreensaver-4.13.tar.bz2: xscreensaver-4.13/hacks/glx/toaster_base.c <==
#include "gllist.h"
static float data[]={
	-0.160224,0.987081,0,-0.242083,0.5,0.052679,
	0.316307,0.948657,0,0.242083,0.5,-0.052679,
	-0.160224,0.987081,0,-0.242083,0.5,-0.052679,
	0.316307,0.948657,0,0.242083,0.5,-0.052679,
	-0.160224,0.987081,0,-0.242083,0.5,0.052679,
	0.316307,0.948657,0,0.242083,0.5,0.052679,
	0.976722,0.21451,0,0.309535,0.432529,-0.052679,
	1,0,0,0.357619,0,0.052679,
	1,0,0,0.357619,0,-0.052679,
	1,0,0,0.357619,0,0.052679,
	0.976722,0.21451,0,0.309535,0.432529,-0.052679,
	0.707166,0.707048,0,0.309535,0.432529,0.052679,
	0.160224,-0.987081,0,0.242083,-0.5,0.052679,
	-0.160224,-0.987081,0,-0.242083,-0.5,-0.052679,
	0.160224,-0.987081,0,0.242083,-0.5,-0.052679,
	-0.160224,-0.987081,0,-0.242083,-0.5,-0.052679,
	0.160224,-0.987081,0,0.242083,-0.5,0.052679,
	-0.707166,-0.707048,0,-0.242083,-0.5,0.052679,
	-0.976722,0.21451,0,-0.309535,0.432529,0.052679,
	-1,0,0,-0.357619,0,-0.052679,
	-1,0,0,-0.357619,0,0.052679,
	-1,0,0,-0.357619,0,-0.052679,
	-0.976722,0.21451,0,-0.309535,0.432529,0.052679,
	-0.584744,0.811218,0,-0.309535,0.432529,-0.052679,
	0,0,-1,-0.309535,0.432529,-0.052679,
	0,0,-1,-0.309535,-0.432529,-0.052679,
	0,0,-1,-0.357619,0,-0.052679,
	0,0,-1,-0.309535,-0.432529,-0.052679,
	0,0,-1,-0.309535,0.432529,-0.052679,
	0,0,-1,-0.292672,0.483132,-0.052679,
	0,0,-1,-0.309535,-0.432529,-0.052679,
	0,0,-1,-0.292672,0.483132,-0.052679,
	0,0,0,-0.292672,-0.483132,-0.052679,
	0,0,0,-0.292672,-0.483132,-0.052679,
	0,0,-1,-0.292672,0.483132,-0.052679,
	0,0,0,-0.242083,0.5,-0.052679,
	0,0,0,-0.292672,-0.483132,-0.052679,
	0,0,0,-0.242083,0.5,-0.052679,
	0,0,-1,-0.242083,-0.5,-0.052679,
	0,0,-1,-0.242083,-0.5,-0.052679,
	0,0,0,-0.242083,0.5,-0.052679,
	0,0,-1,0.242083,0.5,-0.052679,
	0,0,-1,-0.242083,-0.5,-0.052679,
	0,0,-1,0.242083,0.5,-0.052679,
	0,0,0,0.242083,-0.5,-0.052679,
	0,0,0,0.242083,-0.5,-0.052679,
	0,0,-1,0.242083,0.5,-0.052679,
	0,0,-1,0.292672,-0.483132,-0.052679,
	0,0,-1,0.292672,-0.483132,-0.052679,
	0,0,-1,0.242083,0.5,-0.052679,
	0,0,0,0.292672,0.483132,-0.052679,
	0,0,-1,0.292672,-0.483132,-0.052679,
	0,0,0,0.292672,0.483132,-0.052679,
	0,0,0,0.309535,-0.432529,-0.052679,
	0,0,0,0.309535,-0.432529,-0.052679,
	0,0,0,0.292672,0.483132,-0.052679,
	0,0,-1,0.309535,0.432529,-0.052679,
	0,0,0,0.309535,-0.432529,-0.052679,
	0,0,-1,0.309535,0.432529,-0.052679,
	0,0,0,0.357619,0,-0.052679,
	1,0,0,0.357619,0,-0.052679,
	0.994254,-0.107045,0,0.309535,-0.432529,0.052679,
	0.994254,-0.107045,0,0.309535,-0.432529,-0.052679,
	0.994254,-0.107045,0,0.309535,-0.432529,0.052679,
	1,0,0,0.357619,0,-0.052679,
	1,0,0,0.357619,0,0.052679,
	-1,0,0,-0.357619,0,0.052679,
	-0.994254,-0.107045,0,-0.309535,-0.432529,-0.052679,
	-0.994254,-0.107045,0,-0.309535,-0.432529,0.052679,
	-0.994254,-0.107045,0,-0.309535,-0.432529,-0.052679,
	-1,0,0,-0.357619,0,0.052679,
	-1,0,0,-0.357619,0,-0.052679,
	-0.994254,-0.107045,0,-0.309535,-0.432529,0.052679,
	-0.707166,-0.707048,0,-0.292672,-0.483132,-0.052679,
	-0.707166,-0.707048,0,-0.292672,-0.483132,0.052679,
	-0.707166,-0.707048,0,-0.292672,-0.483132,-0.052679,
	-0.994254,-0.107045,0,-0.309535,-0.432529,0.052679,
	-0.994254,-0.107045,0,-0.309535,-0.432529,-0.052679,
	-0.707166,-0.707048,0,-0.242083,-0.5,0.052679,
	-0.707166,-0.707048,0,-0.292672,-0.483132,-0.052679,
	-0.160224,-0.987081,0,-0.242083,-0.5,-0.052679,
	-0.707166,-0.707048,0,-0.292672,-0.483132,-0.052679,
	-0.707166,-0.707048,0,-0.242083,-0.5,0.052679,
	-0.707166,-0.707048,0,-0.292672,-0.483132,0.052679,
	0.994254,-0.107045,0,0.292672,-0.483132,0.052679,
	0.160224,-0.987081,0,0.242083,-0.5,-0.052679,
	0.707166,-0.707048,0,0.292672,-0.483132,-0.052679,
	0.160224,-0.987081,0,0.242083,-0.5,-0.052679,
	0.994254,-0.107045,0,0.292672,-0.483132,0.052679,
	0.160224,-0.987081,0,0.242083,-0.5,0.052679,
	0.994254,-0.107045,0,0.309535,-0.432529,-0.052679,
	0.994254,-0.107045,0,0.292672,-0.483132,0.052679,
	0.707166,-0.707048,0,0.292672,-0.483132,-0.052679,
	0.994254,-0.107045,0,0.292672,-0.483132,0.052679,
	0.994254,-0.107045,0,0.309535,-0.432529,-0.052679,
	0.994254,-0.107045,0,0.309535,-0.432529,0.052679,
	0.316307,0.948657,0,0.242083,0.5,0.052679,
	0.707166,0.707048,0,0.292672,0.483132,-0.052679,
	0.316307,0.948657,0,0.242083,0.5,-0.052679,
	0.707166,0.707048,0,0.292672,0.483132,-0.052679,
	0.316307,0.948657,0,0.242083,0.5,0.052679,
	0.707166,0.707048,0,0.292672,0.483132,0.052679,
	0.707166,0.707048,0,0.292672,0.483132,-0.052679,
	0.707166,0.707048,0,0.309535,0.432529,0.052679,
	0.976722,0.21451,0,0.309535,0.432529,-0.052679,
	0.707166,0.707048,0,0.309535,0.432529,0.052679,
	0.707166,0.707048,0,0.292672,0.483132,-0.052679,
	0.707166,0.707048,0,0.292672,0.483132,0.052679,
	-0.160224,0.987081,0,-0.292672,0.483132,0.052679,
	-0.584744,0.811218,0,-0.309535,0.432529,-0.052679,
	-0.976722,0.21451,0,-0.309535,0.432529,0.052679,
	-0.584744,0.811218,0,-0.309535,0.432529,-0.052679,
	-0.160224,0.987081,0,-0.292672,0.483132,0.052679,
	-0.487642,0.873044,0,-0.292672,0.483132,-0.052679,
	-0.160224,0.987081,0,-0.292672,0.483132,0.052679,
	-0.160224,0.987081,0,-0.242083,0.5,-0.052679,
	-0.487642,0.873044,0,-0.292672,0.483132,-0.052679,
	-0.160224,0.987081,0,-0.242083,0.5,-0.052679,
	-0.160224,0.987081,0,-0.292672,0.483132,0.052679,
	-0.160224,0.987081,0,-0.242083,0.5,0.052679
};
static struct gllist frame={GL_N3F_V3F,GL_TRIANGLES,120,data,NULL};
struct gllist *toaster_base=&frame;

==> xscreensaver-5.02.tar.bz2: xscreensaver-5.02/hacks/glx/toaster_base.c <==
#include "gllist.h"
static const float data[]={
	-0.160224,0.987081,0,-0.242083,0.5,0.052679,
	0.316307,0.948657,0,0.242083,0.5,-0.052679,
	-0.160224,0.987081,0,-0.242083,0.5,-0.052679,
	0.316307,0.948657,0,0.242083,0.5,-0.052679,
	-0.160224,0.987081,0,-0.242083,0.5,0.052679,
	0.316307,0.948657,0,0.242083,0.5,0.052679,
	0.976722,0.21451,0,0.309535,0.432529,-0.052679,
	1,0,0,0.357619,0,0.052679,
	1,0,0,0.357619,0,-0.052679,
	1,0,0,0.357619,0,0.052679,
	0.976722,0.21451,0,0.309535,0.432529,-0.052679,
	0.707166,0.707048,0,0.309535,0.432529,0.052679,
	0.160224,-0.987081,0,0.242083,-0.5,0.052679,
	-0.160224,-0.987081,0,-0.242083,-0.5,-0.052679,
	0.160224,-0.987081,0,0.242083,-0.5,-0.052679,
	-0.160224,-0.987081,0,-0.242083,-0.5,-0.052679,
	0.160224,-0.987081,0,0.242083,-0.5,0.052679,
	-0.707166,-0.707048,0,-0.242083,-0.5,0.052679,
	-0.976722,0.21451,0,-0.309535,0.432529,0.052679,
	-1,0,0,-0.357619,0,-0.052679,
	-1,0,0,-0.357619,0,0.052679,
	-1,0,0,-0.357619,0,-0.052679,
	-0.976722,0.21451,0,-0.309535,0.432529,0.052679,
	-0.584744,0.811218,0,-0.309535,0.432529,-0.052679,
	0,0,-1,-0.309535,0.432529,-0.052679,
	0,0,-1,-0.309535,-0.432529,-0.052679,
	0,0,-1,-0.357619,0,-0.052679,
	0,0,-1,-0.309535,-0.432529,-0.052679,
	0,0,-1,-0.309535,0.432529,-0.052679,
	0,0,-1,-0.292672,0.483132,-0.052679,
	0,0,-1,-0.309535,-0.432529,-0.052679,
	0,0,-1,-0.292672,0.483132,-0.052679,
	0,0,0,-0.292672,-0.483132,-0.052679,
	0,0,0,-0.292672,-0.483132,-0.052679,
	0,0,-1,-0.292672,0.483132,-0.052679,
	0,0,0,-0.242083,0.5,-0.052679,
	0,0,0,-0.292672,-0.483132,-0.052679,
	0,0,0,-0.242083,0.5,-0.052679,
	0,0,-1,-0.242083,-0.5,-0.052679,
	0,0,-1,-0.242083,-0.5,-0.052679,
	0,0,0,-0.242083,0.5,-0.052679,
	0,0,-1,0.242083,0.5,-0.052679,
	0,0,-1,-0.242083,-0.5,-0.052679,
	0,0,-1,0.242083,0.5,-0.052679,
	0,0,0,0.242083,-0.5,-0.052679,
	0,0,0,0.242083,-0.5,-0.052679,
	0,0,-1,0.242083,0.5,-0.052679,
	0,0,-1,0.292672,-0.483132,-0.052679,
	0,0,-1,0.292672,-0.483132,-0.052679,
	0,0,-1,0.242083,0.5,-0.052679,
	0,0,0,0.292672,0.483132,-0.052679,
	0,0,-1,0.292672,-0.483132,-0.052679,
	0,0,0,0.292672,0.483132,-0.052679,
	0,0,0,0.309535,-0.432529,-0.052679,
	0,0,0,0.309535,-0.432529,-0.052679,
	0,0,0,0.292672,0.483132,-0.052679,
	0,0,-1,0.309535,0.432529,-0.052679,
	0,0,0,0.309535,-0.432529,-0.052679,
	0,0,-1,0.309535,0.432529,-0.052679,
	0,0,0,0.357619,0,-0.052679,
	1,0,0,0.357619,0,-0.052679,
	0.994254,-0.107045,0,0.309535,-0.432529,0.052679,
	0.994254,-0.107045,0,0.309535,-0.432529,-0.052679,
	0.994254,-0.107045,0,0.309535,-0.432529,0.052679,
	1,0,0,0.357619,0,-0.052679,
	1,0,0,0.357619,0,0.052679,
	-1,0,0,-0.357619,0,0.052679,
	-0.994254,-0.107045,0,-0.309535,-0.432529,-0.052679,
	-0.994254,-0.107045,0,-0.309535,-0.432529,0.052679,
	-0.994254,-0.107045,0,-0.309535,-0.432529,-0.052679,
	-1,0,0,-0.357619,0,0.052679,
	-1,0,0,-0.357619,0,-0.052679,
	-0.994254,-0.107045,0,-0.309535,-0.432529,0.052679,
	-0.707166,-0.707048,0,-0.292672,-0.483132,-0.052679,
	-0.707166,-0.707048,0,-0.292672,-0.483132,0.052679,
	-0.707166,-0.707048,0,-0.292672,-0.483132,-0.052679,
	-0.994254,-0.107045,0,-0.309535,-0.432529,0.052679,
	-0.994254,-0.107045,0,-0.309535,-0.432529,-0.052679,
	-0.707166,-0.707048,0,-0.242083,-0.5,0.052679,
	-0.707166,-0.707048,0,-0.292672,-0.483132,-0.052679,
	-0.160224,-0.987081,0,-0.242083,-0.5,-0.052679,
	-0.707166,-0.707048,0,-0.292672,-0.483132,-0.052679,
	-0.707166,-0.707048,0,-0.242083,-0.5,0.052679,
	-0.707166,-0.707048,0,-0.292672,-0.483132,0.052679,
	0.994254,-0.107045,0,0.292672,-0.483132,0.052679,
	0.160224,-0.987081,0,0.242083,-0.5,-0.052679,
	0.707166,-0.707048,0,0.292672,-0.483132,-0.052679,
	0.160224,-0.987081,0,0.242083,-0.5,-0.052679,
	0.994254,-0.107045,0,0.292672,-0.483132,0.052679,
	0.160224,-0.987081,0,0.242083,-0.5,0.052679,
	0.994254,-0.107045,0,0.309535,-0.432529,-0.052679,
	0.994254,-0.107045,0,0.292672,-0.483132,0.052679,
	0.707166,-0.707048,0,0.292672,-0.483132,-0.052679,
	0.994254,-0.107045,0,0.292672,-0.483132,0.052679,
	0.994254,-0.107045,0,0.309535,-0.432529,-0.052679,
	0.994254,-0.107045,0,0.309535,-0.432529,0.052679,
	0.316307,0.948657,0,0.242083,0.5,0.052679,
	0.707166,0.707048,0,0.292672,0.483132,-0.052679,
	0.316307,0.948657,0,0.242083,0.5,-0.052679,
	0.707166,0.707048,0,0.292672,0.483132,-0.052679,
	0.316307,0.948657,0,0.242083,0.5,0.052679,
	0.707166,0.707048,0,0.292672,0.483132,0.052679,
	0.707166,0.707048,0,0.292672,0.483132,-0.052679,
	0.707166,0.707048,0,0.309535,0.432529,0.052679,
	0.976722,0.21451,0,0.309535,0.432529,-0.052679,
	0.707166,0.707048,0,0.309535,0.432529,0.052679,
	0.707166,0.707048,0,0.292672,0.483132,-0.052679,
	0.707166,0.707048,0,0.292672,0.483132,0.052679,
	-0.160224,0.987081,0,-0.292672,0.483132,0.052679,
	-0.584744,0.811218,0,-0.309535,0.432529,-0.052679,
	-0.976722,0.21451,0,-0.309535,0.432529,0.052679,
	-0.584744,0.811218,0,-0.309535,0.432529,-0.052679,
	-0.160224,0.987081,0,-0.292672,0.483132,0.052679,
	-0.487642,0.873044,0,-0.292672,0.483132,-0.052679,
	-0.160224,0.987081,0,-0.292672,0.483132,0.052679,
	-0.160224,0.987081,0,-0.242083,0.5,-0.052679,
	-0.487642,0.873044,0,-0.292672,0.483132,-0.052679,
	-0.160224,0.987081,0,-0.242083,0.5,-0.052679,
	-0.160224,0.987081,0,-0.292672,0.483132,0.052679,
	-0.160224,0.987081,0,-0.242083,0.5,0.052679
};
static const struct gllist frame={GL_N3F_V3F,GL_TRIANGLES,120,data,NULL};
const struct gllist *toaster_base=&frame;
